import sys
import unittest
import tempfile

from binarycpython.utils.grid import Population

class test_Population(unittest.TestCase):
    """
    Unittests for function
    """

    def test_setup(self):
        test_pop = Population()

        self.assertTrue('orbital_period' in test_pop.defaults)
        self.assertTrue('metallicity' in test_pop.defaults)
        self.assertNotIn('help_all', test_pop.cleaned_up_defaults)
        self.assertEqual(test_pop.bse_options, {})
        self.assertEqual(test_pop.custom_options, {})
        self.assertEqual(test_pop.argline_dict, {})
        self.assertEqual(test_pop.persistent_data_memory_dict, {})
        self.assertTrue(test_pop.grid_options['parse_function']==None)
        self.assertTrue(isinstance(test_pop.grid_options['_main_pid'], int))

    def test_set(self):
        test_pop = Population()
        test_pop.set(amt_cores=2)
        test_pop.set(M_1=10)
        test_pop.set(data_dir='/tmp/binary_c_python')
        test_pop.set(ensemble_filter_SUPERNOVAE=1)

        self.assertIn('data_dir', test_pop.custom_options)
        self.assertEqual(test_pop.custom_options['data_dir'], '/tmp/binary_c_python')

        # 
        self.assertTrue(test_pop.bse_options['M_1']==10)
        self.assertTrue(test_pop.bse_options['ensemble_filter_SUPERNOVAE']==1)

        #
        self.assertTrue(test_pop.grid_options['amt_cores']==2)


    def test_cmdline(self):
        cmdline_arg = '--cmdline \"metallicity=0.0002\"'
        sys.argv = ['script', '--cmdline', "metallicity=0.0002"]
        test_pop = Population()
        test_pop.parse_cmdline()
        print(test_pop.bse_options)

        self.assertTrue(test_pop.bse_options['metallicity']==0.0002)




if __name__ == "__main__":
    unittest.main()
